code.test.base.listener


bulk-printerclj

(bulk-printer {:keys [results]})

prints out the end summary

prints out the end summary
raw docstring

check-error-accumulatorclj

(check-error-accumulator {:keys [result]})

accumulator for errors on checks

accumulator for errors on checks
raw docstring

check-printerclj

(check-printer {:keys [result]})

prints out result per check

prints out result per check
raw docstring

fact-accumulatorclj

(fact-accumulator {:keys [id meta results]})

accumulator for fact results

accumulator for fact results
raw docstring

fact-printerclj

(fact-printer {:keys [meta results skipped]})

prints out results after every fact

prints out results after every fact
raw docstring

form-error-accumulatorclj

(form-error-accumulator {:keys [result]})

accumulator for thrown errors

accumulator for thrown errors
raw docstring

form-printerclj

(form-printer {:keys [result]})

prints out result for each form

prints out result for each form
raw docstring

install-listenersclj

(install-listeners)

installs all listeners

installs all listeners
raw docstring

result-functionclj

(result-function result)

returns the preferred function identifier for a result.

Uses explicit :refer first, then the consolidated :function field, which may itself come from explicit metadata or form inference.

returns the preferred function identifier for a result.

Uses explicit `:refer` first, then the consolidated `:function` field,
which may itself come from explicit metadata or form inference.
raw docstring

result-nameclj

(result-name result)

returns the preferred display name for a result.

Uses :refer, then inferred :function, then :desc, then :id.

returns the preferred display name for a result.

Uses `:refer`, then inferred `:function`, then `:desc`, then `:id`.
raw docstring

summarise-evaluateclj

(summarise-evaluate result)

extract the form into a valid format

extract the form into a valid format
raw docstring

summarise-verifyclj

(summarise-verify result)

extract the comparison into a valid format

extract the comparison into a valid format
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries