code.test.base.print


format-diffclj

(format-diff diff)

formats a diff

formats a diff
sourceraw docstring

format-diff-mapclj

(format-diff-map diff indent)

formats a map diff

formats a map diff
sourceraw docstring

format-diff-seqclj

(format-diff-seq diff indent)

formats a seq diff

formats a seq diff
sourceraw docstring

(print-fact {:keys [path name ns line desc refer] :as meta} results)

outputs the description for a fact form that contains many statements

outputs the description for a fact form that contains many statements
sourceraw docstring

(print-failed {:keys [name actual check parent checker on-error] :as summary})

prints failed info

prints failed info
sourceraw docstring

(print-on-error color on-error)

prints debug info

prints debug info
sourceraw docstring

(print-preliminary title
                   color
                   {:keys [path name ns line desc form original check]
                    :as summary})

prints preliminary info

prints preliminary info
sourceraw docstring

(print-success {:keys [name check] :as summary})

outputs the description for a successful test

outputs the description for a successful test
sourceraw docstring

(print-summary {:keys [files throw facts checks passed failed timeout queued]
                :as result})

outputs the description for an entire test run

outputs the description for an entire test run
sourceraw docstring

(print-throw {:keys [name data on-error] :as summary})

prints throw info

prints throw info
sourceraw docstring

(print-timeout {:keys [name data actual check parent] :as summary})

prints timeout info

prints timeout info
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries