(create-fact meta body)creates a fact given meta and body
creates a fact given meta and body
(fact desc & body)top level macro for test definitions
top level macro for test definitions
(fact-eval {:keys [ns id] :as fpkg})creates the forms in eval mode
creates the forms in eval mode
(fact-id {:keys [id refer] :as m} desc)creates an id from fact data
(fact-id {} "hello there") => 'test-hello-there
creates an id from fact data
(fact-id {} "hello there")
=> 'test-hello-there(fact-prepare-core desc? body meta)prepares fact for a core form
prepares fact for a core form
(fact-prepare-meta id meta desc body)parses and converts fact to symbols
(fact-prepare-meta 'test-hello {} "hello" '(1 => 1))
parses and converts fact to symbols
(fact-prepare-meta 'test-hello
{}
"hello"
'(1 => 1))(fact-skip? x)checks if form should be skipped
(fact-skip? '(fact:component)) => true
checks if form should be skipped (fact-skip? '(fact:component)) => true
(fact-thunk {:keys [full] :as fpkg})creates a thunk form
creates a thunk form
(fact:all)(fact:all ns)returns all facts in namespace
returns all facts in namespace
(fact:compile fpkg meta)recompiles fact with a different global
recompiles fact with a different global
(fact:exec)(fact:exec id)(fact:exec ns id)runs main hook for fact form
runs main hook for fact form
(fact:get)(fact:get id)(fact:get ns id)gets elements of the current fact
gets elements of the current fact
(fact:missing)(fact:missing ns)returns all missing facts for a given namespace
returns all missing facts for a given namespace
(fact:setup)runs setup hook for current fact
runs setup hook for current fact
(fact:setup?)checks if setup hook has been ran
checks if setup hook has been ran
(fact:symbol)gets the current fact symbol
gets the current fact symbol
(fact:teardown)runs teardown hook for current fact
runs teardown hook for current fact
(fact:template desc & body)adds a template to the file
adds a template to the file
(install-fact meta body)installs the current fact
installs the current fact
(rewrite-top-level body)(rewrite-top-level [x y z & more :as arr] out)creates a sequence of pairs from a loose sequence (rewrite-top-level '[(def a 1) (+ a 3) => 5]) (contains-in '[{:type :form, :meta {:line 8, :column 12}, :form '(def a 1)} {:type :test-equal, :meta {:line 9, :column 12}, :input {:form '(+ a 3)}, :output {:form 5}}])
creates a sequence of pairs from a loose sequence
(rewrite-top-level '[(def a 1)
(+ a 3)
=> 5])
(contains-in '[{:type :form,
:meta {:line 8, :column 12},
:form '(def a 1)}
{:type :test-equal,
:meta {:line 9, :column 12},
:input {:form '(+ a 3)},
:output {:form 5}}])cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |