(-main & args)main entry point for leiningen
(task/-main)
main entry point for leiningen (task/-main)
(print-options)(print-options opts)output options for test results
(task/print-options) => #{:disable :default :all :current :help}
(task/print-options :default) => #{:print-bulk :print-failed :print-throw}
output options for test results
(task/print-options)
=> #{:disable :default :all :current :help}
(task/print-options :default)
=> #{:print-bulk :print-failed :print-throw}(resolve-files files)(resolve-files files project)resolves a file or file list to test namespaces
resolves a file or file list to test namespaces
(run)(run ns)(run ns params)(run ns params project)(run ns params lookup project)runs all tests
(task/run :list)
(task/run 'std.lib.foundation) ;; {:files 1, :throw 0, :facts 8, :checks 18, :passed 18, :failed 0} => map?
runs all tests
(task/run :list)
(task/run 'std.lib.foundation)
;; {:files 1, :throw 0, :facts 8, :checks 18, :passed 18, :failed 0}
=> map?(run-errored)runs only the tests that have errored
(task/run-errored)
runs only the tests that have errored (task/run-errored)
(run:current)(run:current ns)(run:current ns params)(run:current ns params project)(run:current ns params lookup project)runs the current namespace
runs the current namespace
(run:interrupt)(run:load)(run:load ns)(run:load ns params)(run:load ns params project)(run:load ns params lookup project)load test namespace
load test namespace
(run:test)(run:test ns)(run:test ns params)(run:test ns params project)(run:test ns params lookup project)runs loaded tests
runs loaded tests
(run:unload)(run:unload ns)(run:unload ns params)(run:unload ns params project)(run:unload ns params lookup project)unloads the test namespace
unloads the test namespace
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |