code.test.base.executive


+latest+clj


accumulateclj

(accumulate func id)

accumulates test results from various facts and files into a single data structure

accumulates test results from various facts and files into a single data structure
raw docstring

announce-artifactsclj

(announce-artifacts artifacts)

prints save notices for written artifacts

prints save notices for written artifacts
raw docstring

artifact-noticesclj

(artifact-notices {:keys [report-path run-path history-path]})

returns any save notices for written artifacts

returns any save notices for written artifacts
raw docstring

eval-namespaceclj

(eval-namespace ns {:keys [run-id] :as params} lookup project)

evaluates the code within a specified namespace

evaluates the code within a specified namespace
raw docstring

history-file-pathclj

(history-file-path {:keys [run-path]} params)

returns the output path for saved run history

returns the output path for saved run history
raw docstring

interimclj

(interim facts)

summary function for accumulated results

summary function for accumulated results
raw docstring

load-namespaceclj

(load-namespace ns _ lookup project)

loads a given namespace for testing

loads a given namespace for testing
raw docstring

report->run-pathclj

(report->run-path report-path)

returns the repl helper path for a saved test report

returns the repl helper path for a saved test report
raw docstring

report-ednclj

(report-edn x)

coerces a report value into an EDN-safe shape

coerces a report value into an EDN-safe shape
raw docstring

report-edn-safe?clj

(report-edn-safe? x)

checks if a value can be written as EDN without coercion

checks if a value can be written as EDN without coercion
raw docstring

report-file-pathclj

(report-file-path)

returns the output path for a saved test report

returns the output path for a saved test report
raw docstring

retrieve-lineclj

(retrieve-line key results)

returns the line of the test

returns the line of the test
raw docstring

run-currentclj

(run-current ns params lookup project)

runs the current namespace (which can be a non test namespace)

runs the current namespace (which can be a non test namespace)
raw docstring

run-file-formclj

(run-file-form selector params)

creates the repl helper form for rerunning tests

creates the repl helper form for rerunning tests
raw docstring

run-file-paramsclj

(run-file-params params)

removes internal/default params from the saved repl run helper

removes internal/default params from the saved repl run helper
raw docstring

run-file-pathclj

(run-file-path report-path params)

returns the output path for a saved repl run helper

returns the output path for a saved repl run helper
raw docstring

run-namespaceclj

(run-namespace ns params lookup project)

loads and run the namespace

loads and run the namespace
raw docstring

save-artifactclj

(save-artifact _ path content)

saves a generated test artifact

saves a generated test artifact
raw docstring

save-reportclj

(save-report items)
(save-report items selector params)

saves the report to .hara/runs

saves the report to .hara/runs
raw docstring

save-report-pathsclj

(save-report-paths items selector params)

writes report artifacts and returns the written paths

writes report artifacts and returns the written paths
raw docstring

save-run-historyclj

(save-run-history items selector params artifacts)

appends the saved run metadata to csv history

appends the saved run metadata to csv history
raw docstring

summariseclj

(summarise items)

creates a summary of given results

creates a summary of given results
raw docstring

summarise-bulkclj

(summarise-bulk _ items _)

creates a summary of all bulk results

creates a summary of all bulk results
raw docstring

test-namespaceclj

(test-namespace ns {:keys [run-id test] :as params} lookup project)

runs a loaded namespace

runs a loaded namespace
raw docstring

unload-namespaceclj

(unload-namespace ns _ lookup project)

unloads a given namespace for testing

unloads a given namespace for testing
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries