(accumulate func id)accumulates test results from various facts and files into a single data structure
accumulates test results from various facts and files into a single data structure
(announce-artifacts artifacts)prints save notices for written artifacts
prints save notices for written artifacts
(artifact-notices {:keys [report-path run-path history-path]})returns any save notices for written artifacts
returns any save notices for written artifacts
(eval-namespace ns {:keys [run-id] :as params} lookup project)evaluates the code within a specified namespace
evaluates the code within a specified namespace
(history-file-path {:keys [run-path]} params)returns the output path for saved run history
returns the output path for saved run history
(interim facts)summary function for accumulated results
summary function for accumulated results
(load-namespace ns _ lookup project)loads a given namespace for testing
loads a given namespace for testing
(report->run-path report-path)returns the repl helper path for a saved test report
returns the repl helper path for a saved test report
(report-edn x)coerces a report value into an EDN-safe shape
coerces a report value into an EDN-safe shape
(report-edn-safe? x)checks if a value can be written as EDN without coercion
checks if a value can be written as EDN without coercion
(report-file-path)returns the output path for a saved test report
returns the output path for a saved test report
(retrieve-line key results)returns the line of the test
returns the line of the test
(run-current ns params lookup project)runs the current namespace (which can be a non test namespace)
runs the current namespace (which can be a non test namespace)
(run-file-form selector params)creates the repl helper form for rerunning tests
creates the repl helper form for rerunning tests
(run-file-params params)removes internal/default params from the saved repl run helper
removes internal/default params from the saved repl run helper
(run-file-path report-path params)returns the output path for a saved repl run helper
returns the output path for a saved repl run helper
(run-namespace ns params lookup project)loads and run the namespace
loads and run the namespace
(save-artifact _ path content)saves a generated test artifact
saves a generated test artifact
(save-report items)(save-report items selector params)saves the report to .hara/runs
saves the report to .hara/runs
(save-report-paths items selector params)writes report artifacts and returns the written paths
writes report artifacts and returns the written paths
(save-run-history items selector params artifacts)appends the saved run metadata to csv history
appends the saved run metadata to csv history
(summarise items)creates a summary of given results
creates a summary of given results
(summarise-bulk _ items _)creates a summary of all bulk results
creates a summary of all bulk results
(test-namespace ns {:keys [run-id test] :as params} lookup project)runs a loaded namespace
runs a loaded namespace
(unload-namespace ns _ lookup project)unloads a given namespace for testing
unloads a given namespace for testing
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |