code.test.base.print


format-diffclj

(format-diff diff)

formats a diff

formats a diff
raw docstring

format-diff-mapclj

(format-diff-map diff indent)

formats a map diff

formats a map diff
raw docstring

format-diff-seqclj

(format-diff-seq diff indent)

formats a seq diff

formats a seq diff
raw docstring

(print-fact {:keys [path name ns line desc refer] :as meta} results)

outputs the description for a fact form that contains many statements

outputs the description for a fact form that contains many statements
raw docstring

(print-failed {:keys [name actual check parent checker] :as summary})

prints failed info

prints failed info
raw docstring

(print-preliminary title
                   color
                   {:keys [path name ns line desc form original check]
                    :as summary})

prints preliminary info

prints preliminary info
raw docstring

(print-success {:keys [name check] :as summary})

outputs the description for a successful test

outputs the description for a successful test
raw docstring

(print-summary {:keys [files throw facts checks passed failed timeout queued]
                :as result})

outputs the description for an entire test run

outputs the description for an entire test run
raw docstring

(print-throw {:keys [name data] :as summary})

prints throw info

prints throw info
raw docstring

(print-timeout {:keys [name data actual check parent] :as summary})

prints timeout info

prints timeout info
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries